package com.ynet.life.util;

import java.io.FileWriter;
import java.io.IOException;
import java.io.PrintWriter;
import java.io.Writer;

public class CSVWriter {

   PrintWriter pw;
   boolean forceQuotes;
   char separator;
   boolean wasPreviousField;
   String comment;
   String lineSeparator;


   public CSVWriter(PrintWriter pw, boolean forceQuotes, char separator, String lineSeparator) {
      this.wasPreviousField = false;
      this.pw = pw;
      this.forceQuotes = forceQuotes;
      this.separator = separator;
      this.comment = "# ";
      this.lineSeparator = lineSeparator;
   }

   public CSVWriter(Writer w, boolean forceQuotes, char separator, String lineSeparator) {
      this((PrintWriter)(new PrintWriter(w)), forceQuotes, separator, lineSeparator);
   }

   public CSVWriter(PrintWriter pw) {
      this.wasPreviousField = false;
      this.pw = pw;
      this.forceQuotes = false;
      this.separator = 44;
      this.comment = "# ";
      this.lineSeparator = System.getProperty("line.separator");
   }

   public CSVWriter(Writer w) {
      this((PrintWriter)(new PrintWriter(w)));
   }

   public CSVWriter(PrintWriter pw, char comment) {
      this.wasPreviousField = false;
      this.pw = pw;
      this.forceQuotes = false;
      this.separator = 44;
      this.comment = String.valueOf(comment) + " ";
      this.lineSeparator = System.getProperty("line.separator");
   }

   public CSVWriter(Writer w, char comment) {
      this((PrintWriter)(new PrintWriter(w)), comment);
   }

   public void writeCommentln(String text) {
      if(this.wasPreviousField) {
         this.writeln();
      }

      this.pw.print(this.comment);
      this.write(text);
      this.writeln();
   }

   public void writeln(String token) {
      this.write(token);
      this.writeln();
   }

   public void writeln() {
      this.wasPreviousField = false;
      this.pw.print(this.lineSeparator);
   }

   public void writeln(String[] line) {
      for(int ii = 0; ii < line.length; ++ii) {
         this.write(line[ii]);
      }

      this.writeln();
   }

   public void write(String s) {
      if(this.wasPreviousField) {
         this.pw.print(this.separator);
      }

      if(s == null) {
         this.pw.print("");
      } else {
         int i;
         char c;
         if(s.indexOf(34) >= 0) {
            this.pw.print('\"');

            for(i = 0; i < s.length(); ++i) {
               if((c = s.charAt(i)) == 34) {
                  this.pw.print("\"\"");
               } else {
                  this.pw.print(c);
               }
            }

            this.pw.print('\"');
         } else if(s.indexOf(10) >= 0) {
            this.pw.print('\"');

            for(i = 0; i < s.length(); ++i) {
               if((c = s.charAt(i)) == 10) {
                  this.pw.print("\\n");
               } else {
                  this.pw.print(c);
               }
            }

            this.pw.print('\"');
         } else if(!this.forceQuotes && s.indexOf(this.separator) < 0) {
            this.pw.print(s);
         } else {
            this.pw.print('\"');
            this.pw.print(s);
            this.pw.print('\"');
         }

         this.wasPreviousField = true;
      }
   }

   public void close() {
      if(this.pw != null) {
         this.pw.close();
         this.pw = null;
      }

   }

   public static void main(String[] args) {
      try {
         PrintWriter e = new PrintWriter(new FileWriter(args[0]));
         CSVWriter e1;
         (e1 = new CSVWriter(e, false, ',', System.getProperty("line.separator"))).writeCommentln("This is a test csv-file: \'" + args[0] + "\'");
         e1.write("abc");
         e1.write("def");
         e1.write("g h i");
         e1.write("jk,l");
         e1.write("m\"n\'o ");
         e1.writeln();
         e1.write("m\"n\'o ");
         e1.write("    ");
         e1.write("a");
         e1.write("x,y,z");
         e1.write("x;y;z");
         e1.writeln();
         e1.writeln((String[])(new String[]{"This", "is", "an", "array."}));
         e1.close();
      } catch (IOException var2) {
         var2.printStackTrace();
         System.out.println(var2.getMessage());
      }
   }
}
